# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._models_py3 import AccessPolicy
from ._models_py3 import AppendPositionAccessConditions
from ._models_py3 import ArrowConfiguration
from ._models_py3 import ArrowField
from ._models_py3 import BlobFlatListSegment
from ._models_py3 import BlobHTTPHeaders
from ._models_py3 import BlobHierarchyListSegment
from ._models_py3 import BlobItemInternal
from ._models_py3 import BlobMetadata
from ._models_py3 import BlobName
from ._models_py3 import BlobPrefix
from ._models_py3 import BlobPropertiesInternal
from ._models_py3 import BlobTag
from ._models_py3 import BlobTags
from ._models_py3 import Block
from ._models_py3 import BlockList
from ._models_py3 import BlockLookupList
from ._models_py3 import ClearRange
from ._models_py3 import ContainerCpkScopeInfo
from ._models_py3 import ContainerItem
from ._models_py3 import ContainerProperties
from ._models_py3 import CorsRule
from ._models_py3 import CpkInfo
from ._models_py3 import CpkScopeInfo
from ._models_py3 import DelimitedTextConfiguration
from ._models_py3 import FilterBlobItem
from ._models_py3 import FilterBlobSegment
from ._models_py3 import GeoReplication
from ._models_py3 import JsonTextConfiguration
from ._models_py3 import KeyInfo
from ._models_py3 import LeaseAccessConditions
from ._models_py3 import ListBlobsFlatSegmentResponse
from ._models_py3 import ListBlobsHierarchySegmentResponse
from ._models_py3 import ListContainersSegmentResponse
from ._models_py3 import Logging
from ._models_py3 import Metrics
from ._models_py3 import ModifiedAccessConditions
from ._models_py3 import PageList
from ._models_py3 import PageRange
from ._models_py3 import QueryFormat
from ._models_py3 import QueryRequest
from ._models_py3 import QuerySerialization
from ._models_py3 import RetentionPolicy
from ._models_py3 import SequenceNumberAccessConditions
from ._models_py3 import SignedIdentifier
from ._models_py3 import SourceModifiedAccessConditions
from ._models_py3 import StaticWebsite
from ._models_py3 import StorageError
from ._models_py3 import StorageServiceProperties
from ._models_py3 import StorageServiceStats
from ._models_py3 import UserDelegationKey

from ._azure_blob_storage_enums import AccessTier
from ._azure_blob_storage_enums import AccessTierOptional
from ._azure_blob_storage_enums import AccessTierRequired
from ._azure_blob_storage_enums import AccountKind
from ._azure_blob_storage_enums import ArchiveStatus
from ._azure_blob_storage_enums import BlobCopySourceTags
from ._azure_blob_storage_enums import BlobExpiryOptions
from ._azure_blob_storage_enums import BlobImmutabilityPolicyMode
from ._azure_blob_storage_enums import BlobType
from ._azure_blob_storage_enums import BlockListType
from ._azure_blob_storage_enums import CopyStatusType
from ._azure_blob_storage_enums import DeleteSnapshotsOptionType
from ._azure_blob_storage_enums import EncryptionAlgorithmType
from ._azure_blob_storage_enums import FilterBlobsIncludeItem
from ._azure_blob_storage_enums import GeoReplicationStatusType
from ._azure_blob_storage_enums import LeaseDurationType
from ._azure_blob_storage_enums import LeaseStateType
from ._azure_blob_storage_enums import LeaseStatusType
from ._azure_blob_storage_enums import ListBlobsIncludeItem
from ._azure_blob_storage_enums import ListContainersIncludeType
from ._azure_blob_storage_enums import PremiumPageBlobAccessTier
from ._azure_blob_storage_enums import PublicAccessType
from ._azure_blob_storage_enums import QueryFormatType
from ._azure_blob_storage_enums import RehydratePriority
from ._azure_blob_storage_enums import SequenceNumberActionType
from ._azure_blob_storage_enums import SkuName
from ._azure_blob_storage_enums import StorageErrorCode
from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AccessPolicy",
    "AppendPositionAccessConditions",
    "ArrowConfiguration",
    "ArrowField",
    "BlobFlatListSegment",
    "BlobHTTPHeaders",
    "BlobHierarchyListSegment",
    "BlobItemInternal",
    "BlobMetadata",
    "BlobName",
    "BlobPrefix",
    "BlobPropertiesInternal",
    "BlobTag",
    "BlobTags",
    "Block",
    "BlockList",
    "BlockLookupList",
    "ClearRange",
    "ContainerCpkScopeInfo",
    "ContainerItem",
    "ContainerProperties",
    "CorsRule",
    "CpkInfo",
    "CpkScopeInfo",
    "DelimitedTextConfiguration",
    "FilterBlobItem",
    "FilterBlobSegment",
    "GeoReplication",
    "JsonTextConfiguration",
    "KeyInfo",
    "LeaseAccessConditions",
    "ListBlobsFlatSegmentResponse",
    "ListBlobsHierarchySegmentResponse",
    "ListContainersSegmentResponse",
    "Logging",
    "Metrics",
    "ModifiedAccessConditions",
    "PageList",
    "PageRange",
    "QueryFormat",
    "QueryRequest",
    "QuerySerialization",
    "RetentionPolicy",
    "SequenceNumberAccessConditions",
    "SignedIdentifier",
    "SourceModifiedAccessConditions",
    "StaticWebsite",
    "StorageError",
    "StorageServiceProperties",
    "StorageServiceStats",
    "UserDelegationKey",
    "AccessTier",
    "AccessTierOptional",
    "AccessTierRequired",
    "AccountKind",
    "ArchiveStatus",
    "BlobCopySourceTags",
    "BlobExpiryOptions",
    "BlobImmutabilityPolicyMode",
    "BlobType",
    "BlockListType",
    "CopyStatusType",
    "DeleteSnapshotsOptionType",
    "EncryptionAlgorithmType",
    "FilterBlobsIncludeItem",
    "GeoReplicationStatusType",
    "LeaseDurationType",
    "LeaseStateType",
    "LeaseStatusType",
    "ListBlobsIncludeItem",
    "ListContainersIncludeType",
    "PremiumPageBlobAccessTier",
    "PublicAccessType",
    "QueryFormatType",
    "RehydratePriority",
    "SequenceNumberActionType",
    "SkuName",
    "StorageErrorCode",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()



# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
"""Customize generated code here.

Follow our quickstart for examples: https://aka.ms/azsdk/python/dpcodegen/python/customize
"""
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from typing import List
__all__ = []  # type: List[str]  # Add all objects you want publicly available to users at this package level


def patch_sdk():
    """Do not remove from this file.

    `patch_sdk` is a last resort escape hatch that allows you to do customizations
    you can't accomplish using the techniques described in
    https://aka.ms/azsdk/python/dpcodegen/python/customize
    """
